@@ -18,7 +18,7 @@ blav_model_test <- function(lavmodel       = NULL,
     ## marginal log-likelihood approximation
     ## needs original partable with rhos
     if("syntax" %in% names(jagextra)){
-        warning("blavaan WARNING: Marginal log-likelihood cannot be approximated when there is additional JAGS syntax.")
+        warning("blavaan WARNING: Marginal log-likelihood cannot be approximated when there is additional JAGS syntax.", call. = FALSE)
         mll <- NA
     } else {
         mll <- try(margloglik(lavpartable, lavmodel, lavoptions, 
