@@ -52,9 +52,9 @@ dpriors <- function(..., target="stan"){
 
 jagpriors <- function(nu="dnorm(0,1e-3)", alpha="dnorm(0,1e-2)",
                     lambda="dnorm(0,1e-2)", beta="dnorm(0,1e-2)",
-                    itheta="dgamma(1,.5)[sd]", ipsi="dgamma(1,.5)[sd]",
+                    itheta="dgamma(1,.5)[prec]", ipsi="dgamma(1,.5)[prec]",
                     rho="dbeta(1,1)", ibpsi="dwish(iden,3)",
-                    tau="dnorm(0,.1)", delta="dgamma(1,.5)[sd]"){
+                    tau="dnorm(0,.1)", delta="dgamma(1,.5)[prec]"){
 
   dp <- c(nu=nu, alpha=alpha, lambda=lambda, beta=beta,
           itheta=itheta, ipsi=ipsi, rho=rho, ibpsi=ibpsi,
@@ -81,11 +81,11 @@ stanpriors <- function(nu="normal(0,32)",
 
 stanclassicpriors <- function(nu="normal(0,1000^.5)",
                               alpha="normal(0,10)", lambda="normal(0,10)",
-                              beta="normal(0,10)", itheta="gamma(1,.5)[sd]",
-                              ipsi="gamma(1,.5)[sd]", rho="beta(1,1)",
+                              beta="normal(0,10)", itheta="gamma(1,.5)[prec]",
+                              ipsi="gamma(1,.5)[prec]", rho="beta(1,1)",
                               ibpsi="wishart(3,iden)",
                               tau="normal(0,10^.5)",
-                              delta="gamma(1,.5)[sd]"){
+                              delta="gamma(1,.5)[prec]"){
 
   dp <- c(nu=nu, alpha=alpha, lambda=lambda, beta=beta,
           itheta=itheta, ipsi=ipsi, rho=rho, ibpsi=ibpsi,
